/*
 * File:    TypeKTemperature.ino
 * (c)2014 Forward Computing and Control Pty. Ltd
 * see http://www.pfod.com.au
 *
 *  This is an example for for the pfodMAX31855 library for the Adafruit Thermocouple Amplifier MAX31855 breakout board
 *  http://www.adafruit.com/products/269
 *   and type K therocouple
 *  http://www.adafruit.com/products/270
 *
 *  The library differs from the one provided by Adafruit in that
 * the library does not have any delays and returns the raw reading as an int.
 * This means the Arduino is not locked up waiting for a reading and the integer
 * raw reading can be efficiently averaged before converting to a float for display.
 *
 * This library also returns the correct reading for temperatures <0 degC
 * 
 * NOTE: No argument constructor uses DI_Pin = A5;  CLK_Pin = A3; CS_Pin = A4; 
 *
 * To start a measurement call 
 * triggerSensor() 
 *
 * triggerSensor can be called every loop as subsequent calls do nothing until a reading has been returned by 
 * getTypeKTemperature();
 * 
 * Calls to getTypeKTemperature() will return pfodMAX31855.NO_DATA (0) until a reading is available
 * When a reading is available getTypeKTemperature() will return either the raw reading (16*Kelvin)
 * or < pfodMAX31855.NO_DATA if error (pfodMAX31855.FAULT_OPEN_CIRCUIT (-1) or pfodMAX31855.FAULT_TO_VCC (-2) or pfodMAX31855.FAULT_TO_GND (-3) )
 *
*/

#include "pfodMAX31855.h"

pfodMAX31855 typeKTemp;
unsigned long readingTimer;

void setup() {
  Serial.begin(9600);
  for (int i=5; i>0; i--) {
    delay(1000);
    Serial.print(i);
    Serial.print(" ");
  }
  Serial.println();
  readingTimer = millis();
}

void loop() {
  if ((millis() - readingTimer) >= 1000) {
    typeKTemp.triggerSensor();
    readingTimer += 1000; // reset
  }
  int reading = typeKTemp.getTypeKTemperature();

  if (reading != typeKTemp.NO_DATA) { // have a reading
    Serial.print(millis()/1000.0); // output secs since restart
    Serial.print(F(",Sec,")); // csv comma separator
    if (reading < typeKTemp.NO_DATA) {
      Serial.println(reading);
      Serial.println(F(" ,Invalid Reading, ,Invalid Reading"));
    } else {
      Serial.print(typeKTemp.convertToFahrenheit(reading));
      Serial.print(F(",F,"));
      Serial.print(typeKTemp.convertToCelsius(reading));
      Serial.println(F(",C"));
    }
  }
}

